#[non_exhaustive]pub enum OwnedFormatItem {
Literal(Box<[u8]>),
StringLiteral(Box<str>),
Component(Component),
Compound(Box<[Self]>),
Optional(Box<Self>),
First(Box<[Self]>),
}alloc and (crate features formatting or parsing) only.Expand description
A complete description of how to format and parse a type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Literal(Box<[u8]>)
use StringLiteral instead; raw bytes are not recommended
Bytes that are formatted as-is.
Note: These bytes should be UTF-8, but are not required to be. The value is passed
through String::from_utf8_lossy when necessary.
StringLiteral(Box<str>)
A string that is formatted as-is.
Component(Component)
A minimal representation of a single non-literal item.
Compound(Box<[Self]>)
A series of literals or components that collectively form a partial or complete description.
Optional(Box<Self>)
A FormatItem that may or may not be present when parsing. If parsing fails, there
will be no effect on the resulting struct.
This variant has no effect on formatting, as the value is guaranteed to be present.
First(Box<[Self]>)